Module models

Module models 

The request and response types Fizzy speaks, generated from the model.

Structs

AccessToken
AccessToken, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Account
Account, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
AccountExport
AccountExport, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
AccountSettings
AccountSettings, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Activity
Activity, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
ActivityEventable
ActivityEventable, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
ActivityParticulars
ActivityParticulars, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
AssignCardRequestContent
AssignCardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
BadRequestErrorResponseContent
BadRequestErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Board
Board, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
BoardAccessUser
BoardAccessUser, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
BoardAccesses
BoardAccesses, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
BulkReadNotificationsRequestContent
BulkReadNotificationsRequestContent. Built by hand, so it derives Default and takes ..Default::default().
Card
Card, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
CardRef
CardRef, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Color
Color, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Column
Column, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Comment
Comment, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
CompleteJoinRequestContent
CompleteJoinRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CompleteSignupRequestContent
CompleteSignupRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateAccessTokenRequestContent
CreateAccessTokenRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateBoardRequestContent
CreateBoardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateCardReactionRequestContent
CreateCardReactionRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateCardRequestContent
CreateCardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateColumnRequestContent
CreateColumnRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateCommentReactionRequestContent
CreateCommentReactionRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateCommentRequestContent
CreateCommentRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateDirectUploadRequestContent
CreateDirectUploadRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreatePushSubscriptionRequestContent
CreatePushSubscriptionRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateSessionRequestContent
CreateSessionRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateStepRequestContent
CreateStepRequestContent. Built by hand, so it derives Default and takes ..Default::default().
CreateWebhookRequestContent
CreateWebhookRequestContent. Built by hand, so it derives Default and takes ..Default::default().
DataExport
DataExport, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
DirectUpload
DirectUpload, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
DirectUploadHeaders
DirectUploadHeaders, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
DirectUploadMetadata
DirectUploadMetadata, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
ForbiddenErrorResponseContent
ForbiddenErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Identity
Identity, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
InternalServerErrorResponseContent
InternalServerErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
JoinCode
JoinCode, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
MoveCardRequestContent
MoveCardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
NotFoundErrorResponseContent
NotFoundErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Notification
Notification, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
NotificationCard
NotificationCard, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
NotificationSettings
NotificationSettings, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
PendingAuthentication
PendingAuthentication, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
RateLimitErrorResponseContent
RateLimitErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Reaction
Reaction, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
RedeemMagicLinkRequestContent
RedeemMagicLinkRequestContent. Built by hand, so it derives Default and takes ..Default::default().
RegisterDeviceRequestContent
RegisterDeviceRequestContent. Built by hand, so it derives Default and takes ..Default::default().
RequestEmailAddressChangeRequestContent
RequestEmailAddressChangeRequestContent. Built by hand, so it derives Default and takes ..Default::default().
RichTextBody
RichTextBody, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
SessionAuthorization
SessionAuthorization, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Step
Step, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Tag
Tag, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
TagCardRequestContent
TagCardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
TriageCardRequestContent
TriageCardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UnauthorizedErrorResponseContent
UnauthorizedErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
UpdateAccountEntropyRequestContent
UpdateAccountEntropyRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateAccountSettingsRequestContent
UpdateAccountSettingsRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateBoardEntropyRequestContent
UpdateBoardEntropyRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateBoardInvolvementRequestContent
UpdateBoardInvolvementRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateBoardRequestContent
UpdateBoardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateCardRequestContent
UpdateCardRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateColumnRequestContent
UpdateColumnRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateCommentRequestContent
UpdateCommentRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateJoinCodeRequestContent
UpdateJoinCodeRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateMyTimezoneRequestContent
UpdateMyTimezoneRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateNotificationSettingsRequestContent
UpdateNotificationSettingsRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateStepRequestContent
UpdateStepRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateUserRequestContent
UpdateUserRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateUserRoleRequestContent
UpdateUserRoleRequestContent. Built by hand, so it derives Default and takes ..Default::default().
UpdateWebhookRequestContent
UpdateWebhookRequestContent. Built by hand, so it derives Default and takes ..Default::default().
User
User, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
ValidationErrorResponseContent
ValidationErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Webhook
Webhook, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
WebhookDelivery
WebhookDelivery, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
WebhookDeliveryEvent
WebhookDeliveryEvent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
WebhookDeliveryEventCreator
WebhookDeliveryEventCreator, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
WebhookDeliveryEventEventable
WebhookDeliveryEventEventable, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
WebhookDeliveryRequest
WebhookDeliveryRequest, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
WebhookDeliveryResponse
WebhookDeliveryResponse, as Fizzy sends it. Read-only, so a field added later is not a breaking change.

Type Aliases

CreateAccessTokenResponseContent
CreateAccessTokenResponseContent, as the model names it.
CreateAccountExportResponseContent
CreateAccountExportResponseContent, as the model names it.
CreateBoardResponseContent
CreateBoardResponseContent, as the model names it.
CreateCardReactionResponseContent
CreateCardReactionResponseContent, as the model names it.
CreateCardResponseContent
CreateCardResponseContent, as the model names it.
CreateColumnResponseContent
CreateColumnResponseContent, as the model names it.
CreateCommentReactionResponseContent
CreateCommentReactionResponseContent, as the model names it.
CreateCommentResponseContent
CreateCommentResponseContent, as the model names it.
CreateDirectUploadResponseContent
CreateDirectUploadResponseContent, as the model names it.
CreateSessionResponseContent
CreateSessionResponseContent, as the model names it.
CreateStepResponseContent
CreateStepResponseContent, as the model names it.
CreateUserDataExportResponseContent
CreateUserDataExportResponseContent, as the model names it.
CreateWebhookResponseContent
CreateWebhookResponseContent, as the model names it.
GetAccountExportResponseContent
GetAccountExportResponseContent, as the model names it.
GetAccountSettingsResponseContent
GetAccountSettingsResponseContent, as the model names it.
GetBoardResponseContent
GetBoardResponseContent, as the model names it.
GetCardResponseContent
GetCardResponseContent, as the model names it.
GetColumnResponseContent
GetColumnResponseContent, as the model names it.
GetCommentResponseContent
GetCommentResponseContent, as the model names it.
GetJoinCodeResponseContent
GetJoinCodeResponseContent, as the model names it.
GetMyIdentityResponseContent
GetMyIdentityResponseContent, as the model names it.
GetNotificationSettingsResponseContent
GetNotificationSettingsResponseContent, as the model names it.
GetNotificationTrayResponseContent
GetNotificationTrayResponseContent, as the model names it.
GetStepResponseContent
GetStepResponseContent, as the model names it.
GetUserDataExportResponseContent
GetUserDataExportResponseContent, as the model names it.
GetUserResponseContent
GetUserResponseContent, as the model names it.
GetWebhookResponseContent
GetWebhookResponseContent, as the model names it.
ListAccessTokensResponseContent
ListAccessTokensResponseContent, as the model names it.
ListActivitiesResponseContent
ListActivitiesResponseContent, as the model names it.
ListBoardAccessesResponseContent
ListBoardAccessesResponseContent, as the model names it.
ListBoardsResponseContent
ListBoardsResponseContent, as the model names it.
ListCardReactionsResponseContent
ListCardReactionsResponseContent, as the model names it.
ListCardsResponseContent
ListCardsResponseContent, as the model names it.
ListClosedCardsResponseContent
ListClosedCardsResponseContent, as the model names it.
ListColumnCardsResponseContent
ListColumnCardsResponseContent, as the model names it.
ListColumnsResponseContent
ListColumnsResponseContent, as the model names it.
ListCommentReactionsResponseContent
ListCommentReactionsResponseContent, as the model names it.
ListCommentsResponseContent
ListCommentsResponseContent, as the model names it.
ListNotificationsResponseContent
ListNotificationsResponseContent, as the model names it.
ListPinsResponseContent
ListPinsResponseContent, as the model names it.
ListPostponedCardsResponseContent
ListPostponedCardsResponseContent, as the model names it.
ListStepsResponseContent
ListStepsResponseContent, as the model names it.
ListStreamCardsResponseContent
ListStreamCardsResponseContent, as the model names it.
ListTagsResponseContent
ListTagsResponseContent, as the model names it.
ListUsersResponseContent
ListUsersResponseContent, as the model names it.
ListWebhookDeliveriesResponseContent
ListWebhookDeliveriesResponseContent, as the model names it.
ListWebhooksResponseContent
ListWebhooksResponseContent, as the model names it.
MoveCardResponseContent
MoveCardResponseContent, as the model names it.
RedeemMagicLinkResponseContent
RedeemMagicLinkResponseContent, as the model names it.
SearchCardsResponseContent
SearchCardsResponseContent, as the model names it.
StringMap
StringMap, as the model names it.
UpdateAccountEntropyResponseContent
UpdateAccountEntropyResponseContent, as the model names it.
UpdateBoardEntropyResponseContent
UpdateBoardEntropyResponseContent, as the model names it.
UpdateBoardResponseContent
UpdateBoardResponseContent, as the model names it.
UpdateCardResponseContent
UpdateCardResponseContent, as the model names it.
UpdateColumnResponseContent
UpdateColumnResponseContent, as the model names it.
UpdateCommentResponseContent
UpdateCommentResponseContent, as the model names it.
UpdateStepResponseContent
UpdateStepResponseContent, as the model names it.
UpdateUserResponseContent
UpdateUserResponseContent, as the model names it.
UpdateWebhookResponseContent
UpdateWebhookResponseContent, as the model names it.