#[non_exhaustive]pub struct Retry {
pub max: u32,
pub base_delay_ms: u64,
pub retry_on: &'static [u16],
}Expand description
The retry budget the behavior model gives a route.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max: u32Total attempts, the first included.
base_delay_ms: u64The first backoff, in milliseconds, doubled after every attempt.
retry_on: &'static [u16]The statuses that are resent.