pub struct BoardsService<'a> { /* private fields */ }Expand description
The Boards operations.
Implementations
Sourceimpl<'a> BoardsService<'a>
impl<'a> BoardsService<'a>
Sourcepub async fn create(
&self,
body: &CreateBoardRequestContent,
) -> Result<Board, Error>
pub async fn create( &self, body: &CreateBoardRequestContent, ) -> Result<Board, Error>
CreateBoard — POST /{accountId}/boards.json.
Sent once and never resent.
Sourcepub async fn delete(&self, board_id: &str) -> Result<(), Error>
pub async fn delete(&self, board_id: &str) -> Result<(), Error>
DeleteBoard — DELETE /{accountId}/boards/{boardId}.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn get(&self, board_id: &str) -> Result<Board, Error>
pub async fn get(&self, board_id: &str) -> Result<Board, Error>
GetBoard — GET /{accountId}/boards/{boardId}.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn list(&self) -> Result<Page<Vec<Board>>, Error>
pub async fn list(&self) -> Result<Page<Vec<Board>>, Error>
ListBoards — GET /{accountId}/boards.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.
Sourcepub async fn list_board_accesses(
&self,
board_id: &str,
params: &ListBoardAccessesParams,
) -> Result<BoardAccesses, Error>
pub async fn list_board_accesses( &self, board_id: &str, params: &ListBoardAccessesParams, ) -> Result<BoardAccesses, Error>
ListBoardAccesses — GET /{accountId}/boards/{boardId}/accesses.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn list_closed(
&self,
board_id: &str,
) -> Result<Page<Vec<Card>>, Error>
pub async fn list_closed( &self, board_id: &str, ) -> Result<Page<Vec<Card>>, Error>
ListClosedCards — GET /{accountId}/boards/{boardId}/columns/closed.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.
Sourcepub async fn list_postponed(
&self,
board_id: &str,
) -> Result<Page<Vec<Card>>, Error>
pub async fn list_postponed( &self, board_id: &str, ) -> Result<Page<Vec<Card>>, Error>
ListPostponedCards — GET /{accountId}/boards/{boardId}/columns/not_now.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.
Sourcepub async fn list_stream(
&self,
board_id: &str,
) -> Result<Page<Vec<Card>>, Error>
pub async fn list_stream( &self, board_id: &str, ) -> Result<Page<Vec<Card>>, Error>
ListStreamCards — GET /{accountId}/boards/{boardId}/columns/stream.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.
Sourcepub async fn publish(&self, board_id: &str) -> Result<(), Error>
pub async fn publish(&self, board_id: &str) -> Result<(), Error>
PublishBoard — POST /{accountId}/boards/{boardId}/publication.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.
Sourcepub async fn unpublish(&self, board_id: &str) -> Result<(), Error>
pub async fn unpublish(&self, board_id: &str) -> Result<(), Error>
UnpublishBoard — DELETE /{accountId}/boards/{boardId}/publication.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn update(
&self,
board_id: &str,
body: &UpdateBoardRequestContent,
) -> Result<Board, Error>
pub async fn update( &self, board_id: &str, body: &UpdateBoardRequestContent, ) -> Result<Board, Error>
UpdateBoard — PATCH /{accountId}/boards/{boardId}.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn update_entropy(
&self,
board_id: &str,
body: &UpdateBoardEntropyRequestContent,
) -> Result<Board, Error>
pub async fn update_entropy( &self, board_id: &str, body: &UpdateBoardEntropyRequestContent, ) -> Result<Board, Error>
UpdateBoardEntropy — PUT /{accountId}/boards/{boardId}/entropy.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn update_involvement(
&self,
board_id: &str,
body: &UpdateBoardInvolvementRequestContent,
) -> Result<(), Error>
pub async fn update_involvement( &self, board_id: &str, body: &UpdateBoardInvolvementRequestContent, ) -> Result<(), Error>
UpdateBoardInvolvement — PATCH /{accountId}/boards/{boardId}/involvement.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.