CardsService

Struct CardsService 

pub struct CardsService<'a> { /* private fields */ }
The Cards operations.

Implementations

Source

impl<'a> CardsService<'a>

pub fn scope(&self) -> &Scope<'a>

The client and account these operations send through.

pub async fn assign( &self, card_number: i32, body: &AssignCardRequestContent, ) -> Result<(), Error>

AssignCard — POST /{accountId}/cards/{cardNumber}/assignments.json.

Sent once and never resent.

pub async fn close(&self, card_number: i32) -> Result<(), Error>

CloseCard — POST /{accountId}/cards/{cardNumber}/closure.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.

pub async fn create( &self, body: &CreateCardRequestContent, ) -> Result<Card, Error>

CreateCard — POST /{accountId}/cards.json.

Sent once and never resent.

pub async fn delete(&self, card_number: i32) -> Result<(), Error>

DeleteCard — DELETE /{accountId}/cards/{cardNumber}.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn delete_image(&self, card_number: i32) -> Result<(), Error>

DeleteCardImage — DELETE /{accountId}/cards/{cardNumber}/image.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn get(&self, card_number: i32) -> Result<Card, Error>

GetCard — GET /{accountId}/cards/{cardNumber}.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn gold(&self, card_number: i32) -> Result<(), Error>

GoldCard — POST /{accountId}/cards/{cardNumber}/goldness.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.

pub async fn list( &self, params: &ListCardsParams, ) -> Result<Page<Vec<Card>>, Error>

ListCards — GET /{accountId}/cards.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.

pub async fn list_activities( &self, params: &ListActivitiesParams, ) -> Result<Page<Vec<Activity>>, Error>

ListActivities — GET /{accountId}/activities.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.

pub async fn list_column_cards( &self, board_id: &str, column_id: &str, ) -> Result<Page<Vec<Card>>, Error>

ListColumnCards — GET /{accountId}/boards/{boardId}/columns/{columnId}/cards.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.

pub async fn mark_read(&self, card_number: i32) -> Result<(), Error>

MarkCardRead — POST /{accountId}/cards/{cardNumber}/reading.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.

pub async fn mark_unread(&self, card_number: i32) -> Result<(), Error>

MarkCardUnread — DELETE /{accountId}/cards/{cardNumber}/reading.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn move_to_board( &self, card_number: i32, body: &MoveCardRequestContent, ) -> Result<Card, Error>

MoveCard — PATCH /{accountId}/cards/{cardNumber}/board.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn pin(&self, card_number: i32) -> Result<(), Error>

PinCard — POST /{accountId}/cards/{cardNumber}/pin.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.

pub async fn postpone(&self, card_number: i32) -> Result<(), Error>

PostponeCard — POST /{accountId}/cards/{cardNumber}/not_now.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.

pub async fn publish(&self, card_number: i32) -> Result<(), Error>

PublishCard — POST /{accountId}/cards/{cardNumber}/publish.json.

Sent once and never resent.

pub async fn reopen(&self, card_number: i32) -> Result<(), Error>

ReopenCard — DELETE /{accountId}/cards/{cardNumber}/closure.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn self_assign(&self, card_number: i32) -> Result<(), Error>

SelfAssignCard — POST /{accountId}/cards/{cardNumber}/self_assignment.json.

Sent once and never resent.

pub async fn tag( &self, card_number: i32, body: &TagCardRequestContent, ) -> Result<(), Error>

TagCard — POST /{accountId}/cards/{cardNumber}/taggings.json.

Sent once and never resent.

pub async fn triage( &self, card_number: i32, body: &TriageCardRequestContent, ) -> Result<(), Error>

TriageCard — POST /{accountId}/cards/{cardNumber}/triage.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.

pub async fn un_triage(&self, card_number: i32) -> Result<(), Error>

UnTriageCard — DELETE /{accountId}/cards/{cardNumber}/triage.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn ungold(&self, card_number: i32) -> Result<(), Error>

UngoldCard — DELETE /{accountId}/cards/{cardNumber}/goldness.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn unpin(&self, card_number: i32) -> Result<(), Error>

UnpinCard — DELETE /{accountId}/cards/{cardNumber}/pin.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn unwatch(&self, card_number: i32) -> Result<(), Error>

UnwatchCard — DELETE /{accountId}/cards/{cardNumber}/watch.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn update( &self, card_number: i32, body: &UpdateCardRequestContent, ) -> Result<Card, Error>

UpdateCard — PATCH /{accountId}/cards/{cardNumber}.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.

pub async fn watch(&self, card_number: i32) -> Result<(), Error>

WatchCard — POST /{accountId}/cards/{cardNumber}/watch.json.

Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.