pub struct WebhooksService<'a> { /* private fields */ }Expand description
The Webhooks operations.
Implementations
Sourceimpl<'a> WebhooksService<'a>
impl<'a> WebhooksService<'a>
Sourcepub async fn activate(
&self,
board_id: &str,
webhook_id: &str,
) -> Result<(), Error>
pub async fn activate( &self, board_id: &str, webhook_id: &str, ) -> Result<(), Error>
ActivateWebhook — POST /{accountId}/boards/{boardId}/webhooks/{webhookId}/activation.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503. Idempotent, so a resend is safe.
Sourcepub async fn create(
&self,
board_id: &str,
body: &CreateWebhookRequestContent,
) -> Result<Webhook, Error>
pub async fn create( &self, board_id: &str, body: &CreateWebhookRequestContent, ) -> Result<Webhook, Error>
CreateWebhook — POST /{accountId}/boards/{boardId}/webhooks.json.
Sent once and never resent.
Sourcepub async fn delete(
&self,
board_id: &str,
webhook_id: &str,
) -> Result<(), Error>
pub async fn delete( &self, board_id: &str, webhook_id: &str, ) -> Result<(), Error>
DeleteWebhook — DELETE /{accountId}/boards/{boardId}/webhooks/{webhookId}.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn get(
&self,
board_id: &str,
webhook_id: &str,
) -> Result<Webhook, Error>
pub async fn get( &self, board_id: &str, webhook_id: &str, ) -> Result<Webhook, Error>
GetWebhook — GET /{accountId}/boards/{boardId}/webhooks/{webhookId}.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn list(&self, board_id: &str) -> Result<Vec<Webhook>, Error>
pub async fn list(&self, board_id: &str) -> Result<Vec<Webhook>, Error>
ListWebhooks — GET /{accountId}/boards/{boardId}/webhooks.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Sourcepub async fn list_webhook_deliveries(
&self,
board_id: &str,
webhook_id: &str,
) -> Result<Page<Vec<WebhookDelivery>>, Error>
pub async fn list_webhook_deliveries( &self, board_id: &str, webhook_id: &str, ) -> Result<Page<Vec<WebhookDelivery>>, Error>
ListWebhookDeliveries — GET /{accountId}/boards/{boardId}/webhooks/{webhookId}/deliveries.json.
Sent up to 3 times, backing off from 1000 ms, when the answer is 429, 500 or 503.
Paginated: the answer is a page with page as its cursor, and the next one is read with next_page.