The request and response types Fizzy speaks, generated from the model.
Structs
- Access
Token AccessToken, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Account
Account, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Account
Export AccountExport, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Account
Settings AccountSettings, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Activity
Activity, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Activity
Eventable ActivityEventable, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Activity
Particulars ActivityParticulars, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Assign
Card Request Content AssignCardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- BadRequest
Error Response Content BadRequestErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Board
Board, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Board
Access User BoardAccessUser, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Board
Accesses BoardAccesses, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Bulk
Read Notifications Request Content BulkReadNotificationsRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Card
Card, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- CardRef
CardRef, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Color
Color, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Column
Column, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Comment
Comment, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Complete
Join Request Content CompleteJoinRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Complete
Signup Request Content CompleteSignupRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Access Token Request Content CreateAccessTokenRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Board Request Content CreateBoardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Card Reaction Request Content CreateCardReactionRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Card Request Content CreateCardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Column Request Content CreateColumnRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Comment Reaction Request Content CreateCommentReactionRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Comment Request Content CreateCommentRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Direct Upload Request Content CreateDirectUploadRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Push Subscription Request Content CreatePushSubscriptionRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Session Request Content CreateSessionRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Step Request Content CreateStepRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Create
Webhook Request Content CreateWebhookRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Data
Export DataExport, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Direct
Upload DirectUpload, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Direct
Upload Headers DirectUploadHeaders, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Direct
Upload Metadata DirectUploadMetadata, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Forbidden
Error Response Content ForbiddenErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Identity
Identity, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Internal
Server Error Response Content InternalServerErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Join
Code JoinCode, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Move
Card Request Content MoveCardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- NotFound
Error Response Content NotFoundErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Notification
Notification, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Notification
Card NotificationCard, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Notification
Settings NotificationSettings, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Pending
Authentication PendingAuthentication, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Rate
Limit Error Response Content RateLimitErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Reaction
Reaction, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Redeem
Magic Link Request Content RedeemMagicLinkRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Register
Device Request Content RegisterDeviceRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Request
Email Address Change Request Content RequestEmailAddressChangeRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Rich
Text Body RichTextBody, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Session
Authorization SessionAuthorization, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Step
Step, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Tag
Tag, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- TagCard
Request Content TagCardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Triage
Card Request Content TriageCardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Unauthorized
Error Response Content UnauthorizedErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Update
Account Entropy Request Content UpdateAccountEntropyRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Account Settings Request Content UpdateAccountSettingsRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Board Entropy Request Content UpdateBoardEntropyRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Board Involvement Request Content UpdateBoardInvolvementRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Board Request Content UpdateBoardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Card Request Content UpdateCardRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Column Request Content UpdateColumnRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Comment Request Content UpdateCommentRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Join Code Request Content UpdateJoinCodeRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
MyTimezone Request Content UpdateMyTimezoneRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Notification Settings Request Content UpdateNotificationSettingsRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Step Request Content UpdateStepRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
User Request Content UpdateUserRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
User Role Request Content UpdateUserRoleRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- Update
Webhook Request Content UpdateWebhookRequestContent. Built by hand, so it derivesDefaultand takes..Default::default().- User
User, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Validation
Error Response Content ValidationErrorResponseContent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Webhook, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Delivery WebhookDelivery, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Delivery Event WebhookDeliveryEvent, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Delivery Event Creator WebhookDeliveryEventCreator, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Delivery Event Eventable WebhookDeliveryEventEventable, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Delivery Request WebhookDeliveryRequest, as Fizzy sends it. Read-only, so a field added later is not a breaking change.- Webhook
Delivery Response WebhookDeliveryResponse, as Fizzy sends it. Read-only, so a field added later is not a breaking change.
Type Aliases
- Create
Access Token Response Content CreateAccessTokenResponseContent, as the model names it.- Create
Account Export Response Content CreateAccountExportResponseContent, as the model names it.- Create
Board Response Content CreateBoardResponseContent, as the model names it.- Create
Card Reaction Response Content CreateCardReactionResponseContent, as the model names it.- Create
Card Response Content CreateCardResponseContent, as the model names it.- Create
Column Response Content CreateColumnResponseContent, as the model names it.- Create
Comment Reaction Response Content CreateCommentReactionResponseContent, as the model names it.- Create
Comment Response Content CreateCommentResponseContent, as the model names it.- Create
Direct Upload Response Content CreateDirectUploadResponseContent, as the model names it.- Create
Session Response Content CreateSessionResponseContent, as the model names it.- Create
Step Response Content CreateStepResponseContent, as the model names it.- Create
User Data Export Response Content CreateUserDataExportResponseContent, as the model names it.- Create
Webhook Response Content CreateWebhookResponseContent, as the model names it.- GetAccount
Export Response Content GetAccountExportResponseContent, as the model names it.- GetAccount
Settings Response Content GetAccountSettingsResponseContent, as the model names it.- GetBoard
Response Content GetBoardResponseContent, as the model names it.- GetCard
Response Content GetCardResponseContent, as the model names it.- GetColumn
Response Content GetColumnResponseContent, as the model names it.- GetComment
Response Content GetCommentResponseContent, as the model names it.- GetJoin
Code Response Content GetJoinCodeResponseContent, as the model names it.- GetMy
Identity Response Content GetMyIdentityResponseContent, as the model names it.- GetNotification
Settings Response Content GetNotificationSettingsResponseContent, as the model names it.- GetNotification
Tray Response Content GetNotificationTrayResponseContent, as the model names it.- GetStep
Response Content GetStepResponseContent, as the model names it.- GetUser
Data Export Response Content GetUserDataExportResponseContent, as the model names it.- GetUser
Response Content GetUserResponseContent, as the model names it.- GetWebhook
Response Content GetWebhookResponseContent, as the model names it.- List
Access Tokens Response Content ListAccessTokensResponseContent, as the model names it.- List
Activities Response Content ListActivitiesResponseContent, as the model names it.- List
Board Accesses Response Content ListBoardAccessesResponseContent, as the model names it.- List
Boards Response Content ListBoardsResponseContent, as the model names it.- List
Card Reactions Response Content ListCardReactionsResponseContent, as the model names it.- List
Cards Response Content ListCardsResponseContent, as the model names it.- List
Closed Cards Response Content ListClosedCardsResponseContent, as the model names it.- List
Column Cards Response Content ListColumnCardsResponseContent, as the model names it.- List
Columns Response Content ListColumnsResponseContent, as the model names it.- List
Comment Reactions Response Content ListCommentReactionsResponseContent, as the model names it.- List
Comments Response Content ListCommentsResponseContent, as the model names it.- List
Notifications Response Content ListNotificationsResponseContent, as the model names it.- List
Pins Response Content ListPinsResponseContent, as the model names it.- List
Postponed Cards Response Content ListPostponedCardsResponseContent, as the model names it.- List
Steps Response Content ListStepsResponseContent, as the model names it.- List
Stream Cards Response Content ListStreamCardsResponseContent, as the model names it.- List
Tags Response Content ListTagsResponseContent, as the model names it.- List
Users Response Content ListUsersResponseContent, as the model names it.- List
Webhook Deliveries Response Content ListWebhookDeliveriesResponseContent, as the model names it.- List
Webhooks Response Content ListWebhooksResponseContent, as the model names it.- Move
Card Response Content MoveCardResponseContent, as the model names it.- Redeem
Magic Link Response Content RedeemMagicLinkResponseContent, as the model names it.- Search
Cards Response Content SearchCardsResponseContent, as the model names it.- String
Map StringMap, as the model names it.- Update
Account Entropy Response Content UpdateAccountEntropyResponseContent, as the model names it.- Update
Board Entropy Response Content UpdateBoardEntropyResponseContent, as the model names it.- Update
Board Response Content UpdateBoardResponseContent, as the model names it.- Update
Card Response Content UpdateCardResponseContent, as the model names it.- Update
Column Response Content UpdateColumnResponseContent, as the model names it.- Update
Comment Response Content UpdateCommentResponseContent, as the model names it.- Update
Step Response Content UpdateStepResponseContent, as the model names it.- Update
User Response Content UpdateUserResponseContent, as the model names it.- Update
Webhook Response Content UpdateWebhookResponseContent, as the model names it.